@@ -1,9 +1,6 @@
 /* SOGoUserManager.h - this file is part of SOGo
  *
- * Copyright (C) 2007-2013 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
- *         Francis Lachapelle <flachapelle@inverse.ca>
+ * Copyright (C) 2007-2015 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,6 +58,7 @@
 - (NSArray *) sourceIDsInDomain: (NSString *) domain;
 - (NSArray *) authenticationSourceIDsInDomain: (NSString *) domain;
 - (NSArray *) addressBookSourceIDsInDomain: (NSString *) domain;
+- (BOOL) isDomainDefined: (NSString *) domain;
 
 - (NSObject <SOGoSource> *) sourceWithID: (NSString *) sourceID;
 - (NSDictionary *) metadataForSourceID: (NSString *) sourceID;
@@ -68,10 +66,13 @@
 - (NSDictionary *) contactInfosForUserWithUIDorEmail: (NSString *) uid;
 - (NSDictionary *) contactInfosForUserWithUIDorEmail: (NSString *) uid
                                             inDomain: (NSString *) domain;
+- (NSDictionary *) fetchContactWithUID: (NSString *) uid
+                              inDomain: (NSString *) domain;
 - (NSArray *) fetchContactsMatching: (NSString *) match
                            inDomain: (NSString *) domain;
 - (NSArray *) fetchUsersMatching: (NSString *) filter
                         inDomain: (NSString *) domain;
+- (NSArray *) _compactAndCompleteContacts: (NSEnumerator *) contacts;
 
 - (NSString *) getCNForUID: (NSString *) uid;
 - (NSString *) getEmailForUID: (NSString *) uid;
@@ -82,11 +83,19 @@
 - (NSString *) getLoginForDN: (NSString *) theDN;
 
 - (BOOL) checkLogin: (NSString *) _login
-	   password: (NSString *) _pwd
+           password: (NSString *) _pwd
              domain: (NSString **) _domain
-	       perr: (SOGoPasswordPolicyError *) _perr
-	     expire: (int *) _expire
-	      grace: (int *) _grace;
+               perr: (SOGoPasswordPolicyError *) _perr
+             expire: (int *) _expire
+              grace: (int *) _grace;
+
+- (BOOL) checkLogin: (NSString *) _login
+           password: (NSString *) _pwd
+             domain: (NSString **) _domain
+               perr: (SOGoPasswordPolicyError *) _perr
+             expire: (int *) _expire
+              grace: (int *) _grace
+           useCache: (BOOL) _useCache;
 
 - (BOOL) changePasswordForLogin: (NSString *) login
                        inDomain: (NSString *) domain
