@@ -1,23 +1,22 @@
 /* generic.js - this file is part of SOGo
 
-   Copyright (C) 2005 SKYRIX Software AG
-   Copyright (C) 2006-2012 Inverse
+   Copyright (C) 2006-2014 Inverse
 
- SOGo is free software; you can redistribute it and/or modify it under
- the terms of the GNU Lesser General Public License as published by the
- Free Software Foundation; either version 2, or (at your option) any
- later version.
+   SOGo is free software; you can redistribute it and/or modify it under
+   the terms of the GNU Lesser General Public License as published by the
+   Free Software Foundation; either version 2, or (at your option) any
+   later version.
 
- SOGo is distributed in the hope that it will be useful, but WITHOUT ANY
- WARRANTY; without even the implied warranty of MERCHANTABILITY or
- FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
- License for more details.
+   SOGo is distributed in the hope that it will be useful, but WITHOUT ANY
+   WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
 
- You should have received a copy of the GNU Lesser General Public
- License along with SOGo; see the file COPYING.  If not, write to the
- Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
- 02111-1307, USA.
- */
+   You should have received a copy of the GNU Lesser General Public
+   License along with SOGo; see the file COPYING.  If not, write to the
+   Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.
+*/
 
 var logConsole;
 var logWindow = null;
@@ -45,14 +44,14 @@ var activeAjaxRequests = 0;
 var removeFolderRequestCount = 0;
 
 // Email validation regexp
-var emailRE = /^([\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+\.)*[\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+@((((([a-z0-9]{1}[a-z0-9\-]{0,62}[a-z0-9]{1})|[a-z])\.)+[a-z]{2,6})|(\d{1,3}\.){3}\d{1,3}(\:\d{1,5})?)$/i;
+var emailRE = /^([\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+\.)*[\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+@((((([a-z0-9]{1}[a-z0-9\-]{0,62}[a-z0-9]{1})|[a-z])\.)+[a-z]{2,})|(\d{1,3}\.){3}\d{1,3}(\:\d{1,5})?)$/i;
 
 
 /* This function enables the execution of a wrapper function just before the
- user callback is executed. The wrapper in question executes "preventDefault"
- to the event parameter if and only when "this" is a link. The goal of this
- operation is to prevent links with attached even handlers to be followed,
- including those with an href set to "#". */
+   user callback is executed. The wrapper in question executes "preventDefault"
+   to the event parameter if and only when "this" is a link. The goal of this
+   operation is to prevent links with attached even handlers to be followed,
+   including those with an href set to "#". */
 function clickEventWrapper(functionRef) {
     function button_clickEventWrapper(event) {
         if (this.tagName == "A") {
@@ -65,9 +64,7 @@ function clickEventWrapper(functionRef) {
 }
 
 
-function createElement(tagName, id, classes,
-                       attributes, htmlAttributes,
-                       parentNode) {
+function createElement(tagName, id, classes, attributes, htmlAttributes, parentNode) {
     var newElement = $(document.createElement(tagName));
     if (id)
         newElement.setAttribute("id", id);
@@ -93,6 +90,7 @@ function createElement(tagName, id, classes,
 function URLForFolderID(folderID) {
     var folderInfos = folderID.split(":");
     var url;
+
     if (folderInfos.length > 1) {
         url = UserFolderURL + "../" + encodeURI(folderInfos[0]);
         if (!(folderInfos[0].endsWith('/')
@@ -102,9 +100,8 @@ function URLForFolderID(folderID) {
     }
     else {
         var folderInfo = folderInfos[0];
-        if (ApplicationBaseURL.endsWith('/')
-            && folderInfo.startsWith('/'))
-            folderInfo = folderInfo.substr(1);
+        if (!(folderInfo.startsWith('/')))
+            folderInfo = "/" + folderInfo;
         url = ApplicationBaseURL + encodeURI(folderInfo);
     }
 
@@ -134,7 +131,7 @@ function extractEmailName(mailTo) {
     tmpMailTo = tmpMailTo.replace("&gt;", ">");
     tmpMailTo = tmpMailTo.replace("&amp;", "&");
 
-    var emailNamere = /([ 	]+)?(.+)\ </;
+    var emailNamere = /([       ]+)?(.+)\ </;
     if (emailNamere.test(tmpMailTo)) {
         emailNamere.exec(tmpMailTo);
         emailName = RegExp.$2;
@@ -175,9 +172,7 @@ function sanitizeWindowName(dirtyWindowName) {
 
 function openUserFolderSelector(callback, type) {
     var urlstr = ApplicationBaseURL;
-    if (! urlstr.endsWith('/'))
-        urlstr += '/';
-    urlstr += ("../../" + UserLogin + "/Contacts/userFolders");
+    urlstr += ("/../../" + UserLogin + "/Contacts/userFolders");
 
     var div = $("popupFrame");
     if (div) {
@@ -214,7 +209,7 @@ function openGenericWindow(url, wId) {
         var iframe = div.down("iframe");
         iframe.src = url;
         if (!wId)
-	    wId = "genericFrame";
+            wId = "genericFrame";
         iframe.id = wId;;
         var bgDiv = $("bgFrameDiv");
         if (bgDiv) {
@@ -268,11 +263,11 @@ function openContactWindow(url, wId) {
         else
             wId = sanitizeWindowName(wId);
 
-        var w = window.open(url, wId,
-                            "width=450,height=530,resizable=0,location=0");
-        w.focus();
-
-        return w;
+        $(function() {
+            var w = window.open(url, wId,
+                                "width=460,height=560,resizable=0,location=0");
+            w.focus();
+        }).delay(0.1);
     }
 }
 
@@ -329,22 +324,34 @@ function openMailTo(senderMailTo) {
     }
 
     if (sanitizedAddresses.length > 0)
-        openMailComposeWindow(ApplicationBaseURL
-                              + "../Mail/compose?mailto=" + encodeURIComponent(Object.toJSON(sanitizedAddresses))
-                              + ((subject.length > 0)?"?subject=" + encodeURIComponent(subject):""));
+        $(function() {
+            openMailComposeWindow(ApplicationBaseURL
+                                  + "/../Mail/compose?mailto=" + encodeURIComponent(Object.toJSON(sanitizedAddresses))
+                                  + ((subject.length > 0)?"?subject=" + encodeURIComponent(subject):""));
+        }).delay(0.1);
 
     return false; /* stop following the link */
 }
 
+function onEmailTo(event) {
+    var s = this.innerHTML.strip();
+    if (!/@/.test(s)) {
+        s += ' <' + this.href.substr(7) + '>';
+    }
+    openMailTo(s);
+    Event.stop(event);
+    return false;
+}
+
 function deleteDraft(url) {
     /* this is called by UIxMailEditor with window.opener */
     new Ajax.Request(url, {
-                         asynchronous: false,
-                         method: 'post',
-                         onFailure: function(transport) {
-                             log("draftDeleteCallback: problem during ajax request: " + transport.status);
-                         }
-                     });
+        asynchronous: false,
+        method: 'post',
+        onFailure: function(transport) {
+            log("draftDeleteCallback: problem during ajax request: " + transport.status);
+        }
+    });
 }
 
 function refreshFolderByType(type) {
@@ -375,12 +382,12 @@ function onCASRecoverIFrameLoaded(event) {
         var request = this.request;
         if (request.attempt == 0) {
             window.setTimeout(function() {
-                                  triggerAjaxRequest(request.url,
-                                                     request.callback,
-                                                     request.callbackData,
-                                                     request.content,
-                                                     request.paramHeaders,
-                                                     1); },
+                triggerAjaxRequest(request.url,
+                                   request.callback,
+                                   request.callbackData,
+                                   request.content,
+                                   request.paramHeaders,
+                                   1); },
                               100);
         }
         else {
@@ -433,17 +440,23 @@ function onAjaxRequestStateChange(http) {
 
 /* taken from Lightning */
 function getContrastingTextColor(bgColor) {
-    var calcColor = bgColor.substring(1);
-    var red = parseInt(calcColor.substring(0, 2), 16);
-    var green = parseInt(calcColor.substring(2, 4), 16);
-    var blue = parseInt(calcColor.substring(4, 6), 16);
+    var textColor = "black";
+    if (bgColor) {
+        var calcColor = bgColor.substring(1);
+        var red = parseInt(calcColor.substring(0, 2), 16);
+        var green = parseInt(calcColor.substring(2, 4), 16);
+        var blue = parseInt(calcColor.substring(4, 6), 16);
 
-    // Calculate the brightness (Y) value using the YUV color system.
-    var brightness = (0.299 * red) + (0.587 * green) + (0.114 * blue);
+        // Calculate the brightness (Y) value using the YUV color system.
+        var brightness = (0.299 * red) + (0.587 * green) + (0.114 * blue);
 
-    // Consider all colors with less than 56% brightness as dark colors and
-    // use white as the foreground color, otherwise use black.
-    return ((brightness < 144) ? "white" : "black");
+        // Consider all colors with less than 56% brightness as dark colors and
+        // use white as the foreground color, otherwise use black.
+        if (brightness < 144)
+            textColor = "white";
+    }
+
+    return textColor;
 }
 
 function triggerAjaxRequest(url, callback, userdata, content, headers, attempt) {
@@ -719,8 +732,8 @@ function onRowClick(event, target) {
         $(node).selectElement();
     }
     if (rowIndex != null) {
-	lastClickedRow = rowIndex;
-	lastClickedRowId = node.getAttribute("id");
+        lastClickedRow = rowIndex;
+        lastClickedRowId = node.getAttribute("id");
     }
 
     return true;
@@ -757,7 +770,7 @@ function popupMenu(event, menuId, target) {
     var leftDiff = ((window.width() + deltaX)
                     - (menuLeft + popup.offsetWidth));
     if (leftDiff < 0)
-        menuLeft -= (popup.offsetWidth + 1);
+      menuLeft += leftDiff - 1;
 
     var isVisible = true;
     if (popup.prepareVisibility) {
@@ -842,13 +855,13 @@ function hideMenu(menuNode) {
     Event.fire(menuNode, "contextmenu:hide");
 }
 
-function onMenuEntryClick(event) {
-    var node = event.target;
-
-    id = getParentMenu(node).menuTarget;
-
-    return false;
-}
+//function onMenuEntryClick(event) {
+//    var node = event.target;
+//
+//    id = getParentMenu(node).menuTarget;
+//
+//    return false;
+//}
 
 /* query string */
 
@@ -1348,7 +1361,7 @@ function getListIndexForFolder(items, owner, folderName) {
 
     for (i = 0; i < items.length; i++) {
         if (items[i].id == '/personal') continue;
-        var currentFolderName = items[i].lastChild.nodeValue.strip();
+        var currentFolderName = items[i].childNodesWithTag("span")[0].innerHTML.strip();
         var currentOwner = items[i].readAttribute('owner');
         if (currentOwner == owner) {
             previousOwner = currentOwner;
@@ -1451,32 +1464,34 @@ function showAlarmCallback(http) {
         if (http.responseText.length) {
             var url = http.callbackData;
             var data = http.responseText.evalJSON(true);
-            var msg = _("Reminder:") + " " + data["summary"] + "\n";
+            var msg = _("Reminder") + " " + data["summary"] + "\n";
             if (data["startDate"]) {
-                msg += _("Start:") + " " + data["startDate"];
+                msg += _("Start") + " " + data["startDate"];
                 if (parseInt(data["isAllDay"]) == 0)
                     msg += " - " + data["startTime"];
                 msg += "\n";
             }
             if (data["dueDate"]) {
-                msg += _("Due Date:") + " " + data["dueDate"];
+                msg += _("Due Date") + " " + data["dueDate"];
                 if (data["dueTime"])
                     msg += " - " + data["dueTime"];
                 msg += "\n";
             }
             if (data["location"].length)
-                msg += "\n" + _("Location:") + " " + data["location"];
+                msg += "\n" + _("Location") + " " + data["location"];
             if (data["description"].length)
                 msg += "\n\n" + data["description"];
 
-            window.alert(msg);
+            window.alert(msg.decodeEntities());
             showSelectDialog(data["summary"], _('Snooze for '),
                              { '5': _('5 minutes'),
                                '10': _('10 minutes'),
                                '15': _('15 minutes'),
                                '30': _('30 minutes'),
                                '45': _('45 minutes'),
-                               '60': _('1 hour') }, _('OK'),
+                               '60': _('1 hour'),
+                               '1440': _('1 day') },
+                             _('OK'),
                              snoozeAlarm, url,
                              '10');
         }
@@ -1523,7 +1538,7 @@ function initMenu(menuDIV, callbacks) {
                 }
                 else {
                     node.menuCallback = callback;
-		    node.on("mousedown", onMenuClickHandler);
+                    node.on("mousedown", onMenuClickHandler);
                 }
             }
             else
@@ -1537,14 +1552,14 @@ function openExternalLink(anchor) {
 }
 
 function openAclWindow(url) {
-    var w = window.open(url, "aclWindow",
-                        "width=420,height=300,resizable=1,scrollbars=1,toolbar=0,"
-                        + "location=0,directories=0,status=0,menubar=0"
-                        + ",copyhistory=0");
-    w.opener = window;
-    w.focus();
-
-    return w;
+    $(function () {
+        var w = window.open(url, "aclWindow",
+                            "width=420,height=300,resizable=1,scrollbars=1,toolbar=0,"
+                            + "location=0,directories=0,status=0,menubar=0"
+                            + ",copyhistory=0");
+        w.opener = window;
+        w.focus();
+    }).delay(0.1);
 }
 
 function getUsersRightsWindowHeight() {
@@ -1735,7 +1750,7 @@ function onPreferencesClick(event) {
     }
     else {
         var w = window.open(urlstr, "SOGoPreferences",
-                            "width=580,height=476,resizable=1,scrollbars=0,location=0");
+                            "width=615,height=520,resizable=1,scrollbars=0,location=0");
         w.opener = window;
         w.focus();
     }
@@ -1765,17 +1780,37 @@ function configureLinkBanner() {
     }
 }
 
+function configureLinks(element) {
+    var onAnchorClick = function (event) {
+        if (this.href)
+            window.open(this.href);
+        preventDefault(event);
+    };
+    var anchors = element.getElementsByTagName('a');
+    for (var i = 0; i < anchors.length; i++) {
+        var anchor = $(anchors[i]);
+        if (!anchor.href && anchor.readAttribute("moz-do-not-send")) {
+            anchor.writeAttribute("moz-do-not-send", false);
+            anchor.removeClassName("moz-txt-link-abbreviated");
+            anchor.href = "mailto:" + anchors[i].innerHTML;
+        }
+        if (anchor.href.substring(0,7) == "mailto:") {
+            anchor.observe("click", onEmailTo);
+            if (typeof onEmailAddressClick == 'function')
+                anchor.observe("contextmenu", onEmailAddressClick);
+            anchor.writeAttribute("moz-do-not-send", false);
+        }
+        else if (!anchor.id)
+            anchor.observe("click", onAnchorClick);
+    }
+}
+
 function CurrentModule() {
     var module = null;
     if (ApplicationBaseURL) {
         var parts = ApplicationBaseURL.split("/");
         var last = parts.length - 1;
-        while (last > -1 && parts[last] == "") {
-            last--;
-        }
-        if (last > -1) {
-            module = parts[last];
-        }
+        module = parts[last];
     }
 
     return module;
@@ -1925,7 +1960,7 @@ AIM = {
         d.innerHTML = '<iframe class="hidden" src="about:blank" id="'
             + n + '" name="' + n + '" onload="AIM.loaded(\'' + n + '\')"></iframe>';
         document.body.appendChild(d);
-        var i = $(n); // TODO: useful?
+        var i = $(n);
         if (c && typeof(c.onComplete) == 'function')
             i.onComplete = c.onComplete;
         return n;
@@ -1936,27 +1971,28 @@ AIM = {
     },
 
     submit: function(f, c) {
-        AIM.form(f, AIM.frame(c));
+        var id = AIM.frame(c);
+        AIM.form(f, id);
         if (c && typeof(c.onStart) == 'function')
             return c.onStart();
         else
-            return true;
+            return $(id);
     },
 
     loaded: function(id) {
         var i = $(id);
+        var d;
         if (i.contentDocument) {
-            var d = i.contentDocument;
+            d = i.contentDocument;
         }
         else if (i.contentWindow) {
-            var d = i.contentWindow.document;
+            d = i.contentWindow.document;
         }
         else {
-            var d = window.frames[id].document;
+            d = window.frames[id].document;
         }
         if (d.location.href == "about:blank")
             return;
-
         if (typeof(i.onComplete) == 'function') {
             i.onComplete(Element.allTextContent(d.body));
         }
@@ -1969,7 +2005,7 @@ function createDialog(id, title, legend, content, positionClass) {
     var newDialog = createElement("div", id, ["dialog", positionClass]);
     newDialog.setStyle({"display": "none"});
 
-    if (positionClass == "none") {
+    if (positionClass == "none" || positionClass == "searchMail") {
         var bgDiv = $("bgDialogDiv");
         if (bgDiv) {
             bgDiv.show();
@@ -1984,7 +2020,7 @@ function createDialog(id, title, legend, content, positionClass) {
     var subdiv = createElement("div", null, null, null, null, newDialog);
     if (title && title.length > 0) {
         var titleh3 = createElement("h3", null, null, null, null, subdiv);
-        titleh3.appendChild(document.createTextNode(title));
+        titleh3.update(title);
     }
     if (legend) {
         if (Object.isElement(legend))
@@ -2061,12 +2097,12 @@ function _showConfirmDialog(title, label, callbackYes, callbackNo, yesLabel, noL
     if (dialog) {
         $("bgDialogDiv").show();
 
-	// Update callbacks on buttons
-	var buttons = dialog.getElementsByTagName("a");
-	buttons[0].stopObserving();
-	buttons[0].on("click", callbackYes);
-	buttons[1].stopObserving();
-	buttons[1].on("click", callbackNo || disposeDialog);
+        // Update callbacks on buttons
+        var buttons = dialog.getElementsByTagName("a");
+        buttons[0].stopObserving();
+        buttons[0].on("click", callbackYes);
+        buttons[1].stopObserving();
+        buttons[1].on("click", callbackNo || disposeDialog);
     }
     else {
         var fields = createElement("p");
@@ -2098,19 +2134,19 @@ function _showPromptDialog(title, label, callback, defaultValue) {
     v = defaultValue?defaultValue:"";
     if (dialog) {
         $("bgDialogDiv").show();
-	dialog.down("input").value = v;
+        dialog.down("input").value = v;
     }
     else {
         var fields = createElement("p", null, ["prompt"]);
-	fields.appendChild(document.createTextNode(label));
+        fields.appendChild(document.createTextNode(label));
         var input = createElement("input", null, "textField",
-				  { type: "text", "value": v },
-				  { previousValue: v });
-	fields.appendChild(input);
+                                  { type: "text", "value": v },
+                                  { previousValue: v });
+        fields.appendChild(input);
         fields.appendChild(createButton(null,
                                         _("OK"),
                                         callback.bind(input)));
-	fields.appendChild(createButton(null,
+        fields.appendChild(createButton(null,
                                         _("Cancel"),
                                         disposeDialog));
         dialog = createDialog(null,
@@ -2123,7 +2159,10 @@ function _showPromptDialog(title, label, callback, defaultValue) {
     }
     if (Prototype.Browser.IE)
         jQuery('#bgDialogDiv').css('opacity', 0.4);
-    jQuery(dialog).fadeIn('fast', function () { dialog.down("input").focus(); });
+    jQuery(dialog).fadeIn('fast', function () {
+        var input = dialog.down("input");
+        input.selectText(0, input.value.length);
+    });
 }
 
 function showSelectDialog(title, label, options, button, callbackFcn, callbackArg, defaultValue) {
@@ -2142,21 +2181,21 @@ function _showSelectDialog(title, label, options, button, callbackFcn, callbackA
     }
     else {
         var fields = createElement("p", null, []);
-	fields.appendChild(document.createTextNode(label));
+        fields.update(label);
         var select = createElement("select"); //, null, null, { cname: name } );
-	fields.appendChild(select);
+        fields.appendChild(select);
         var values = $H(options).keys();
         for (var i = 0; i < values.length; i++) {
             var option = createElement("option", null, null,
                                        { value: values[i] }, null, select);
-            option.appendChild(document.createTextNode(options[values[i]]));
+            option.update(options[values[i]]);
         }
         fields.appendChild(createElement("br"));
 
         fields.appendChild(createButton(null,
                                         button,
                                         callbackFcn.bind(select, callbackArg)));
-	fields.appendChild(createButton(null,
+        fields.appendChild(createButton(null,
                                         _("Cancel"),
                                         disposeDialog));
         dialog = createDialog(null,
@@ -2168,7 +2207,7 @@ function _showSelectDialog(title, label, options, button, callbackFcn, callbackA
         dialogs[title+label] = dialog;
     }
     if (defaultValue)
-	defaultOption = dialog.down('option[value="'+defaultValue+'"]').selected = true;
+        defaultOption = dialog.down('option[value="'+defaultValue+'"]').selected = true;
     if (Prototype.Browser.IE)
         jQuery('#bgDialogDiv').css('opacity', 0.4);
     jQuery(dialog).fadeIn('fast');
@@ -2193,19 +2232,19 @@ function _showAuthenticationDialog(label, callback) {
     }
     else {
         var fields = createElement("p", null, ["prompt"]);
-	fields.appendChild(document.createTextNode(_("Username:")));
+        fields.appendChild(document.createTextNode(_("Username:")));
         var un_input = createElement("input", null, "textField",
-				     { type: "text", "value": "" });
-	fields.appendChild(un_input);
-	fields.appendChild(document.createTextNode(_("Password:")));
+                                     { type: "text", "value": "" });
+        fields.appendChild(un_input);
+        fields.appendChild(document.createTextNode(_("Password:")));
         var pw_input = createElement("input", null, "textField",
-			             { type: "password", "value": "" });
-	fields.appendChild(pw_input);
+                                     { type: "password", "value": "" });
+        fields.appendChild(pw_input);
         function callbackWrapper() {
             callback(un_input.value, pw_input.value);
         }
         fields.appendChild(createButton(null, _("OK"), callbackWrapper));
-	fields.appendChild(createButton(null, _("Cancel"), disposeDialog));
+        fields.appendChild(createButton(null, _("Cancel"), disposeDialog));
         dialog = createDialog(null, label, null, fields, "none");
         document.body.appendChild(dialog);
         dialogs[label] = dialog;
