@@ -2,18 +2,20 @@
 
 set -e
 
-# This script only works with mysql
-# updates c_cycleinfo to mediumtext
-# http://www.sogo.nu/bugs/view.php?id=1848
-# the field length was actually changed somewhere between 1.3.2 and 1.3.3
-# but no one reported any breakage.
-
-# this script only works with MySQL
+# This script only works with MySQL
+# updates c_partstates to mediumtext
+# adds c_description to Calendar quick tables
+# http://www.sogo.nu/bugs/view.php?id=3175
+# the field length was actually changed in v2.2.18
 
 defaultusername=$USER
 defaulthostname=127.0.0.1
 defaultdatabase=$USER
-indextable=$(defaults read sogod OCSFolderInfoURL | awk -F/ '{print $NF}')
+if [ -f /etc/sogo/sogo.conf ];then
+  indextable=$(sogo-tool dump-defaults -f /etc/sogo/sogo.conf | awk -F\" '/ OCSFolderInfoURL =/  {print $2}' |  awk -F/ '{print $NF}')
+else
+  indextable=$(sogo-tool dump-defaults | awk -F\" '/ OCSFolderInfoURL =/  {print $2}' |  awk -F/ '{print $NF}')
+fi
 if [ -z "$indextable" ]; then
   echo "Couldn't fetch OCSFolderInfoURL value, aborting" >&2
   exit 1
@@ -40,21 +42,23 @@ then
 
 sqlscript=""
 
-growVC() {
+adjustSchema() {
     oldIFS="$IFS"
     IFS=" "
-    part="`echo -e \"ALTER TABLE $table MODIFY c_cycleinfo mediumtext;\\n\"`";
-    sqlscript="$sqlscript$part"
+    part1="`echo -e \"ALTER TABLE $table MODIFY c_partstates mediumtext;\\n\"`";
+    part2="`echo -e \"ALTER TABLE $table ADD COLUMN c_description mediumtext;\\n\"`";
+    sqlscript="$sqlscript$part1$part2"
     IFS="$oldIFS"
 }
 
 echo "This script will ask for the sql password twice" >&2
-echo "Converting c_cycleinfo from VARCHAR(1000) to mediumtext in calendar quick tables" >&2
+echo "Converting c_partstates from VARCHAR(255) to mediumtext in calendar quick tables" >&2
+echo "Adding c_description column as mediumtext in calendar quick tables" >&2
 tables=`mysql -p -s -u $username -h $hostname $database -e "select SUBSTRING_INDEX(c_quick_location, '/', -1) from $indextable where c_path3 = 'Calendar';"`
 
 for table in $tables;
 do
-  growVC
+  adjustSchema
 done
 
 echo "$sqlscript" | mysql -p -s -u $username -h $hostname $database
